DROP TABLE SHOP_CATEGORIES
DROP SEQUENCE SHOP_CATEGORIES_ID_SEQ
CREATE TABLE SHOP_CATEGORIES(CATEGORY_ID INTEGER NOT NULL, SHOP_ID VARCHAR(255) NOT NULL, NAME VARCHAR(255) default '' NOT NULL, IMAGE_ID INTEGER default 0, IMAGE_EXT VARCHAR(4), PRODUCT_COUNT INTEGER default 0 NOT NULL)
CREATE SEQUENCE SHOP_CATEGORIES_ID_SEQ INCREMENT BY 1 START WITH 1 MAXVALUE 1.0E28 MINVALUE 1 NOCYCLE CACHE 20 NOORDER
CREATE UNIQUE INDEX SHOP_CATEGORIES_ID ON SHOP_CATEGORIES("CATEGORY_ID")
CREATE OR REPLACE TRIGGER SHOP_CATEGORIES_ID_TRIGGER BEFORE INSERT ON SHOP_CATEGORIES FOR EACH ROW DECLARE BEGIN select SHOP_CATEGORIES_ID_SEQ.NEXTVAL INTO :NEW.CATEGORY_ID FROM DUAL; END;

DROP TABLE SHOP_DESIGN
CREATE TABLE SHOP_DESIGN(SHOP_ID VARCHAR(255) NOT NULL, NAME VARCHAR(255) default '' NOT NULL, DESIGN_VALUE  VARCHAR(255))

DROP TABLE SHOP_HASHES
CREATE TABLE SHOP_HASHES(SHOP_ID VARCHAR(255) NOT NULL, SHOP_HASH VARCHAR(255) NOT NULL)

DROP TABLE SHOP_ORDERS
DROP SEQUENCE SHOP_ORDERS_ID_SEQ
CREATE TABLE SHOP_ORDERS(SHOP_ID VARCHAR(255) NOT NULL, TRANSATION_ID VARCHAR(255) NOT NULL, CITY VARCHAR(255), ZIP VARCHAR(10) default '' NOT NULL, COUNTRY VARCHAR(255) default '' NOT NULL, STATE VARCHAR(255), ADDRESS2 VARCHAR(255), ADDRESS1 VARCHAR(255) default '' NOT NULL, EMAIL VARCHAR(255) default '' NOT NULL, PHONE VARCHAR(255) default '' NOT NULL, COMPANY VARCHAR(255), LAST_NAME VARCHAR(255) default '' NOT NULL, FIRST_NAME  VARCHAR(255) default '' NOT NULL, ORDER_STATUS VARCHAR(1) default '' NOT NULL, COST FLOAT(11)  default 0 NOT NULL, CREATED_DATE  VARCHAR(50) default '' NOT NULL, ORDER_ID INTEGER NOT NULL, SHOP_ORDER_ID INTEGER NOT NULL, UPDATED_DATE VARCHAR(50) default '' NOT NULL, USER_LOGIN VARCHAR(255) NOT NULL)
CREATE SEQUENCE SHOP_ORDERS_ID_SEQ INCREMENT BY 1 START WITH 1 MAXVALUE 1.0E28 MINVALUE 1 NOCYCLE CACHE 20 NOORDER
CREATE UNIQUE INDEX SHOP_ORDERS_ID ON SHOP_ORDERS("ORDER_ID")
CREATE OR REPLACE TRIGGER SHOP_ORDERS_ID_TRIGGER BEFORE INSERT ON SHOP_ORDERS FOR EACH ROW DECLARE BEGIN select SHOP_ORDERS_ID_SEQ.NEXTVAL INTO :NEW.ORDER_ID FROM DUAL; END;

DROP TABLE SHOP_ORDER_CONTENTS
CREATE TABLE SHOP_ORDER_CONTENTS(SHOP_ID VARCHAR(255) NOT NULL, NAME VARCHAR(255) default '' NOT NULL, ORDER_ID INTEGER NOT NULL, PRICE VARCHAR(255) default 0 NOT NULL, PRODUCT_ID INTEGER NOT NULL, QUANTITY INTEGER default 0 NOT NULL)

DROP TABLE SHOP_PRODUCTS
DROP SEQUENCE SHOP_PRODUCTS_ID_SEQ
CREATE TABLE SHOP_PRODUCTS(SHOP_ID VARCHAR(255) NOT NULL, CATEGORY_NAME VARCHAR(255) default '' NOT NULL, IMAGE_EXT VARCHAR(4), NAME VARCHAR(255) default '' NOT NULL, PRODUCT_ID INTEGER  NOT NULL, CATEGORY_ID INTEGER default 0 NOT NULL, IMAGE_ID INTEGER, BRIEF_DESCRIPTION BLOB, DESCRIPTION BLOB, PRICE FLOAT default 0 NOT NULL)
CREATE SEQUENCE SHOP_PRODUCTS_ID_SEQ INCREMENT BY 1 START WITH 1 MAXVALUE 1.0E28 MINVALUE 1 NOCYCLE CACHE 20 NOORDER
CREATE UNIQUE INDEX SHOP_PRODUCTS_ID ON SHOP_PRODUCTS("PRODUCT_ID")
CREATE OR REPLACE TRIGGER SHOP_PRODUCTS_ID_TRIGGER BEFORE INSERT ON SHOP_PRODUCTS FOR EACH ROW DECLARE BEGIN select SHOP_PRODUCTS_ID_SEQ.NEXTVAL INTO :NEW.PRODUCT_ID FROM DUAL; END;

DROP TABLE SHOP_SETTINGS
CREATE TABLE SHOP_SETTINGS (SHOP_ID VARCHAR(255) NOT NULL, NAME VARCHAR(255) default '' NOT NULL, SETTING_VALUE  CLOB)

DROP TABLE SHOP_USERS
DROP SEQUENCE SHOP_USERS_ID_SEQ
CREATE TABLE SHOP_USERS (zip varchar(10) default '' NOT NULL, IS_PWD_REQUESTED VARCHAR(36), ADDRESS1 VARCHAR(255) default '' NOT NULL, ADDRESS2 VARCHAR(255), CITY VARCHAR(255), COMPANY VARCHAR(255), COUNTRY VARCHAR(255) default '' NOT NULL, EMAIL VARCHAR(255) default '' NOT NULL, FIRST_NAME VARCHAR(255) default '' NOT NULL, LAST_NAME VARCHAR(255) default '' NOT NULL, LOGIN VARCHAR(25) NOT NULL, PWD VARCHAR(36) NOT NULL, PHONE VARCHAR(255) default '' NOT NULL, SHOP_ID VARCHAR(255) NOT NULL, STATE VARCHAR(255), USER_ID INTEGER  NOT NULL)
CREATE SEQUENCE SHOP_USERS_ID_SEQ INCREMENT BY 1 START WITH 1 MAXVALUE 1.0E28 MINVALUE 1 NOCYCLE CACHE 20 NOORDER
CREATE UNIQUE INDEX SHOP_USERS_ID ON SHOP_USERS("USER_ID")
CREATE OR REPLACE TRIGGER SHOP_USERS_ID_TRIGGER BEFORE INSERT ON SHOP_USERS FOR EACH ROW DECLARE BEGIN select SHOP_USERS_ID_SEQ.NEXTVAL INTO :NEW.USER_ID FROM DUAL; END;

DROP TABLE SHOP_PAYMENTS
CREATE TABLE SHOP_PAYMENTS (SHOP_ID VARCHAR(255) NOT NULL, NAME VARCHAR(255) default '' NOT NULL, SETTING_VALUE  CLOB)

